==> klass-model-meta-interface-0.4.0-sources.jar: cool/klass/model/meta/domain/api/projection/ProjectionDataTypeProperty.java <==
/*
 * Copyright 2024 Craig Motlin
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package cool.klass.model.meta.domain.api.projection;

import javax.annotation.Nonnull;

import cool.klass.model.meta.domain.api.property.DataTypeProperty;
import org.eclipse.collections.api.list.ImmutableList;
import org.eclipse.collections.impl.factory.Lists;

public interface ProjectionDataTypeProperty
        extends ProjectionChild
{
    @Override
    default ImmutableList<? extends ProjectionChild> getChildren()
    {
        return Lists.immutable.empty();
    }

    @Override
    default void visit(@Nonnull ProjectionVisitor visitor)
    {
        visitor.visitProjectionDataTypeProperty(this);
    }

    @Override
    default void enter(@Nonnull ProjectionListener listener)
    {
        listener.enterProjectionDataTypeProperty(this);
    }

    @Override
    default void exit(@Nonnull ProjectionListener listener)
    {
        listener.exitProjectionDataTypeProperty(this);
    }

    @Nonnull
    String getHeaderText();

    @Override
    @Nonnull
    DataTypeProperty getProperty();
}

==> klass-model-meta-interface-0.5.0-sources.jar: cool/klass/model/meta/domain/api/projection/ProjectionDataTypeProperty.java <==
/*
 * Copyright 2024 Craig Motlin
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package cool.klass.model.meta.domain.api.projection;

import javax.annotation.Nonnull;

import cool.klass.model.meta.domain.api.property.DataTypeProperty;
import org.eclipse.collections.api.list.ImmutableList;
import org.eclipse.collections.impl.factory.Lists;

public interface ProjectionDataTypeProperty extends ProjectionChild {
    @Override
    default ImmutableList<? extends ProjectionChild> getChildren() {
        return Lists.immutable.empty();
    }

    @Override
    default void visit(@Nonnull ProjectionVisitor visitor) {
        visitor.visitProjectionDataTypeProperty(this);
    }

    @Override
    default void enter(@Nonnull ProjectionListener listener) {
        listener.enterProjectionDataTypeProperty(this);
    }

    @Override
    default void exit(@Nonnull ProjectionListener listener) {
        listener.exitProjectionDataTypeProperty(this);
    }

    @Nonnull
    String getHeaderText();

    @Override
    @Nonnull
    DataTypeProperty getProperty();
}
